import sys
from itertools import count
from pysat.solvers import Solver

if len(sys.argv) == 1:
	print "Provide k on the command-line"
	quit()

# number of colours
r = 2

# length of the monochromatic aritmetic progression to avoid
k = int(sys.argv[1])

def to_word(model):
	return "".join(["1" if x>0 else "0" for x in model])

with Solver(use_timer=True) as s:

	# Start n at k and increase by 1 until a call is UNSAT
	for n in count(k):
		
		# Avoid monochromatic arithmetic progressions
		# that include the integer n
		for b in range(1, n):
			indices = range(n, 0, -b)[:k]
			if len(indices) == k:
				# Only add clauses of length k
				s.add_clause(indices)
				s.add_clause([-x for x in indices])

		result = s.solve()

		if result:
			print "W(%d, %d) > %d by the colouring" % (r, k, n),
			print to_word(s.get_model())
		else:
			print "W(%d, %d) = %d" % (r, k, n)
			print "Time: %.2f seconds" % s.time_accum()
			break
